@@ -5,7 +5,7 @@
 import os
 import time
 import numpy as np
-from .utils import readToGray
+from .utils import readImg
 from .utils import saveNumpy
 
 def preprocess(DIR, classes, name, IMG_SIZE=224, train_size=None, isNormalize=False, isShuffle=True, isSave = True):
@@ -51,7 +51,7 @@ def preprocess(DIR, classes, name, IMG_SIZE=224, train_size=None, isNormalize=Fa
                         image_path = os.path.join(class_path, image)
 
                         # Returns image RESIZED and GRAY
-                        gray = readToGray(image_path, IMG_SIZE)
+                        gray = readImg(image_path, IMG_SIZE)
                         # Normalizing
                         if isNormalize is True:
                             gray = normalize(gray)
