@@ -19,7 +19,7 @@ def readImg(image, IMG_SIZE, channels=1):
     # [INFO] Using the following piece of code results in a 'None' in the training set
     # if image_array == None:
     #     pass
-    if channels is 1:
+    if channels == 1:
         image_array = cv.cvtColor(image_array, cv.COLOR_BGR2GRAY)
 
     image_array = cv.resize(image_array, (IMG_SIZE,IMG_SIZE))
